/*     ____
      /____\ 
      \    /    Gweled
       \  /
        \/

(C) 2003 Sebastien Delestaing <sebastien.delestaing@wanadoo.fr>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>

#include "interface.h"
#include "support.h"

#include "sge_core.h"
#include "board_engine.h"
#include "graphic_engine.h"

// GLOBALS
GnomeProgram *g_program;
GtkWidget *g_main_window;
GtkWidget *g_drawing_area;
GtkWidget *g_progress_bar;
GtkWidget *g_score_label;
GtkWidget *g_bonus_label;
GdkPixmap *g_buffer_pixmap = NULL;
GRand *g_random_generator;

int main (int argc, char **argv)
{
	guint board_engine_id;

	gnome_score_init("gweled");

	g_program = gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE,
					argc, argv,
					GNOME_PARAM_APP_DATADIR, PACKAGE_DATA_DIR,
					NULL);

  sge_init();

	g_random_generator = g_rand_new_with_seed(time (NULL));

  gi_tile_width = 48;
  gi_tile_height = 48;
  gi_difficulty_level = 0;

	g_main_window = create_gweledApp ();
	gtk_window_set_resizable (GTK_WINDOW (g_main_window), FALSE);
	gtk_widget_show (g_main_window);

	g_progress_bar = lookup_widget(GTK_WIDGET (g_main_window), "bonusProgressbar");  
	g_score_label = lookup_widget(GTK_WIDGET (g_main_window), "scoreLabel");  
	g_bonus_label = lookup_widget(GTK_WIDGET (g_main_window), "bonusLabel");  
	g_drawing_area = lookup_widget(GTK_WIDGET (g_main_window), "boardDrawingarea"); 
	gtk_widget_set_size_request (GTK_WIDGET (g_drawing_area), BOARD_WIDTH * gi_tile_width, BOARD_HEIGHT * gi_tile_height);
	gtk_widget_add_events(GTK_WIDGET(g_drawing_area), GDK_BUTTON_PRESS_MASK);

	g_buffer_pixmap = gdk_pixmap_new (g_drawing_area->window, BOARD_WIDTH * gi_tile_width, BOARD_HEIGHT * gi_tile_height, -1);

	gweled_init_glyphs();
	gweled_load_pixmaps();
  gweled_load_font();

	gi_game_running = 0;

	board_engine_id = gtk_timeout_add(100, board_engine_loop, NULL);
  sge_set_drawing_area(g_drawing_area, g_buffer_pixmap, BOARD_WIDTH * gi_tile_width, BOARD_HEIGHT * gi_tile_height);

	gweled_draw_board();
	gweled_draw_message("gweled");

	gtk_main ();

  sge_destroy();
	gtk_timeout_remove(board_engine_id);	
	g_rand_free(g_random_generator);

	return 0;
}

